package bank;


/**
 * Class whose objects represent the automated teller machines of our bank.
 * These machines can operate both online and offline. In the first case, all
 * transactions are directly transfered to the central host of the bank, in the
 * latter case transactions are first buffered (using class
 * <code>OfflineAccountProxy</code> and later written back to the central
 * host.
 */

public class ATM {

    /**
     * @return <code>true</code> iff the ATM is online
     */
    public boolean isOnline () {
    }


    /**
     * Switch the status of <code>this</code> ATM to online or offline.
     * Switching to online will make the terminal write back all buffered
     * transactions to the central host and remove all account proxies.
     * 
     * @param newOnline
     *            <code>true</code> iff the terminal is switched online
     */
    public void setOnline (boolean newOnline) {
    }


    /**
     * Insert the given card into the ATM. This will check whether the card is
     * invalid or the card belongs to a non-existing account (if the terminal is
     * online); in this case the card is directly confiscated
     * 
     * @param card
     *            the card to be inserted
     */
    public void insertCard (BankCard card) {
    }


    /**
     * Eject an inserted card
     *
     * @return the card that was inserted previously
     */
    public BankCard ejectCard () {
    }


    /**
     * Confiscate an inserted card. This invalidates the card; afterwards, the
     * card is no longer regarded as inserted
     */
    public void confiscateCard () {
    }


    /**
     * Enter the PIN that belongs to the currently inserted bank card into the
     * ATM. If the card gets invalidated by the PIN check, it is 
     * confiscated. After having entered the correct PIN, the customer is
     * regarded as authenticated.
     * 
     * @param pin
     *            the PIN that is entered
     */
    public void enterPIN (int pin) {
    }


    /**
     * @return <code>true</code> iff a card is inserted in the ATM
     */
    public boolean cardIsInserted () {
    }


    /**
     * @return <code>true</code> iff a customer is regarded as authenticated,
     *         i.e. if a valid card is inserted and the correct PIN has be
     *         entered
     */
    public boolean customerIsAuthenticated () {
    }


    /**
     * @return the account number of the account that belongs to the currently
     *         inserted card
     */
    public int getAccountNumber () {
    }


    /**
     * Determine the balance of the current account.
     * 
     * @return the balance of the current account, provided that the balance is
     *         available (only in the online case). Otherwise <code>0</code>
     *         is returned
     */
    public int accountBalance () {
    }


    /**
     * Try to withdraw <code>amount</code> from the current account.
     * 
     * @param amount
     *            the amount that is supposed to be withdrawn
     * 
     * @return the amount of money that was sucessfully withdrawn (i.e. in case
     *          of failure the return value is <code>0</code>)
     */
    public int withdraw (int amount) {
    }


    /**
     * Request a printed account statement for the current account
     */
    public void requestAccountStatement () {
    }


    /**
     * Transfer money from the current account to another account. Works
     * only if the ATM is online.
     * 
     * @param amount the amount of money to transfer
     * @param toAccount account number of the destination account
     * @return <code>true</code> if the transfer was successful,
     *         <code>false</code> otherwise
     */
    public boolean transfer (int amount, int toAccount) {
    }
}
